inLock property

  1. @override
bool get inLock
override

For a reentrant lock, whether the current Zone is nested inside a synchronized call on this lock (so a further nested call would not deadlock).

For a non-reentrant lock this simply returns locked; that value does not indicate reentrancy and should not be relied upon, as it may change in the future.

Implementation

@override
bool get inLock => locked;